## Dev

- Clone repository and enter project directory
```
git clone https://github.com/MorriganR/SciPyFST.git
cd SciPyFST
```

- Create virtual enviroment 
```
python -m venv venvdev
```

- Activate virtual enviroment
```
.\venvdev\Scripts\activate.bat
```

- Install all dependencies 
```
pip install -r requirements.txt
```

- Start VS Code 
```
code .
```

- Backup all dependencies 
```
pip freeze > requirements.txt
```

## Installed for Dev
- numpy
- ipykernel
- graphviz
  - add binary https://www.graphviz.org/download/

## Examples
Open example with Google Colab:
https://colab.research.google.com/github/MorriganR/SciPyFST/blob/main/examples/example_07_forColab.ipynb
